Change Log — OppiaMobile 0.1.14 documentation

### Navigation

- index
- previous |
- OppiaMobile 0.1.14 documentation »

# Change Log

## v0.1.15

## v0.1.14

- Fix: https://github.com/DigitalCampus/django-oppia/issues/19

## v0.1.13

- Add a max upload file size (https://github.com/DigitalCampus/django-oppia/issues/8) - this prevents users uploading large course files which may make it difficult for end users to download on slow connections
- Updated mobile scorecard page
- Added extra info on Django admin pages (https://github.com/DigitalCampus/django-oppia/issues/14)

## v0.1.12

- Initial release (all previous versions were for alpha testing)

### Navigation

- index
- previous |
- OppiaMobile 0.1.14 documentation »